==> dj-foundation-pro-1.0.100002.tgz: package/foundation/class/DjColor.js <==

 function DjColor() {
}
export default DjColor
DjColor.test = function () {
  return '我是测试颜色'
}
DjColor.dj_randomColorRGB = function(alpha = 1){
  let red = Math.floor(Math.random()*256);
  let green = Math.floor(Math.random()*256);
  let blue = Math.floor(Math.random()*256);
  return 'rgba('+red+','+green+','+blue+','+alpha+')'
}
DjColor.dj_randomColor16 = function(){
  let red = Math.floor(Math.random()*256);
  let green = Math.floor(Math.random()*256);
  let blue = Math.floor(Math.random()*256);
  return '#'+red.toString(16)+green.toString(16)+blue.toString(16);
}
DjColor.dj_randomHsl = function(){
  let H = Math.random();
  let S = Math.random();
  let L = Math.random();
  return [H, S, L];
}
/**
 * HSL颜色值转换为RGB
 * H，S，L 设定在 [0, 1] 之间
 * **/
DjColor.dj_hslToColorRGB = function(H,S,L){
  let R, G, B;
  if (+S === 0) {
    R = G = B = L; // 饱和度为0 为灰色
  } else {
    let hue2Rgb = function (p, q, t) {
      if (t < 0) t += 1;
      if (t > 1) t -= 1;
      if (t < 1/6) return p + (q - p) * 6 * t;
      if (t < 1/2) return q;
      if (t < 2/3) return p + (q - p) * (2/3 - t) * 6;
      return p;
    };
    let Q = L < 0.5 ? L * (1 + S) : L + S - L * S;
    let P = 2 * L - Q;
    R = hue2Rgb(P, Q, H + 1/3);
    G = hue2Rgb(P, Q, H);
    B = hue2Rgb(P, Q, H - 1/3);
  }
  return [Math.round(R * 255), Math.round(G * 255), Math.round(B * 255)];
}
DjColor.get_randomWarmColor = function(){
  let hsl = DjColor.dj_randomHsl();
  hsl[1] = 0.7 + (hsl[1] * 0.2);
  hsl[2] = 0.4 + (hsl[2] * 0.4);
  hsl = hsl.map(function (item) {
    return parseFloat(item.toFixed(2));
  });
  return 'rgb(' + DjColor.dj_hslToColorRGB(hsl[0],hsl[1],hsl[2]).toString() + ')'
}
DjColor.dj_randomBackgroundColor = function(){
  return {'background-color':DjColor.dj_randomColor16()}
}
DjColor.dj_randomTextColor = function(){
  return {'color':DjColor.dj_randomColor16()}
}
const reg = /^#([0-9a-fA-f]{3}|[0-9a-fA-f]{6})$/;

DjColor.dj_hexTransformRgbColor = function(color,isFull = true){
  let lowerColor = color.toLowerCase();
  if(lowerColor && reg.test(lowerColor)){
    if(lowerColor.length === 4){
      let lowerColorNew = "#";
      for(let i=1; i<4; i+=1){
        lowerColorNew += lowerColor.slice(i,i+1).concat(lowerColor.slice(i,i+1));
      }
      lowerColor = lowerColorNew;
    }
    let mapper = [];
    for(let i=1; i<7; i+=2){
      mapper.push(parseInt("0x"+lowerColor.slice(i,i+2)));
    }
    if (isFull == false){
      return mapper.join(",")
    }else {
      return "rgb(" + mapper.join(",") + ")";
    }
  }else{
    return lowerColor;
  }

}

==> dj-foundation-pro-1.0.1000016.tgz: package/foundation/class/DjColor.js <==

 function DjColor() {
}
export default DjColor
DjColor.test = function () {
  return '我是测试颜色'
}
DjColor.dj_randomColorRGB = function(alpha = 1){
  let red = Math.floor(Math.random()*256);
  let green = Math.floor(Math.random()*256);
  let blue = Math.floor(Math.random()*256);
  return 'rgba('+red+','+green+','+blue+','+alpha+')'
}
DjColor.dj_randomColor16 = function(){
  let red = Math.floor(Math.random()*256);
  let green = Math.floor(Math.random()*256);
  let blue = Math.floor(Math.random()*256);
  return '#'+red.toString(16)+green.toString(16)+blue.toString(16);
}
DjColor.dj_randomHsl = function(){
  let H = Math.random();
  let S = Math.random();
  let L = Math.random();
  return [H, S, L];
}
/**
 * HSL颜色值转换为RGB
 * H，S，L 设定在 [0, 1] 之间
 * **/
DjColor.dj_hslToColorRGB = function(H,S,L){
  let R, G, B;
  if (+S === 0) {
    R = G = B = L; // 饱和度为0 为灰色
  } else {
    let hue2Rgb = function (p, q, t) {
      if (t < 0) t += 1;
      if (t > 1) t -= 1;
      if (t < 1/6) return p + (q - p) * 6 * t;
      if (t < 1/2) return q;
      if (t < 2/3) return p + (q - p) * (2/3 - t) * 6;
      return p;
    };
    let Q = L < 0.5 ? L * (1 + S) : L + S - L * S;
    let P = 2 * L - Q;
    R = hue2Rgb(P, Q, H + 1/3);
    G = hue2Rgb(P, Q, H);
    B = hue2Rgb(P, Q, H - 1/3);
  }
  return [Math.round(R * 255), Math.round(G * 255), Math.round(B * 255)];
}
DjColor.get_randomWarmColor = function(){
  let hsl = DjColor.dj_randomHsl();
  hsl[1] = 0.7 + (hsl[1] * 0.2);
  hsl[2] = 0.4 + (hsl[2] * 0.4);
  hsl = hsl.map(function (item) {
    return parseFloat(item.toFixed(2));
  });
  return 'rgb(' + DjColor.dj_hslToColorRGB(hsl[0],hsl[1],hsl[2]).toString() + ')'
}
DjColor.dj_randomBackgroundColor = function(){
  return {'background-color':DjColor.dj_randomColor16()}
}
DjColor.dj_randomTextColor = function(){
  return {'color':DjColor.dj_randomColor16()}
}

 DjColor.dj_hexTransformRgbColor = function(hex,opacity){
   let rgbaColor = "";
   let reg = /^#[\da-f]{6}$/i;
   if (reg.test(hex)) {
     rgbaColor = `rgba(${parseInt("0x" + hex.slice(1, 3))},${parseInt(
       "0x" + hex.slice(3, 5)
     )},${parseInt("0x" + hex.slice(5, 7))},${opacity})`;
   }
   return rgbaColor;

 }
